==> haskell-what4-1.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-what4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 what4
version:              1.1
visibility:           public
id:                   what4-1.1-JFb2glpD9gv7gUNa55Ywhj
key:                  what4-1.1-JFb2glpD9gv7gUNa55Ywhj
license:              BSD-3-Clause
copyright:            (c) Galois, Inc 2014-2021
maintainer:           jhendrix@galois.com, rdockins@galois.com
author:               Galois Inc.
homepage:             https://github.com/GaloisInc/what4
synopsis:             Solver-agnostic symbolic values support for issuing queries
description:
    What4 is a generic library for representing values as symbolic formulae which may
    contain references to symbolic values, representing unknown variables.
    It provides support for communicating with a variety of SAT and SMT solvers,
    including Z3, CVC4, Yices, Boolector, STP, and dReal.
    The data representation types make heavy use of GADT-style type indices
    to ensure type-correct manipulation of symbolic values.

category:             Formal Methods, Theorem Provers, Symbolic Computation, SMT
abi:                  6564672c9ff79bbeba22fe8911d22c68
exposed:              True
exposed-modules:
    Test.Verification What4.BaseTypes What4.Concrete What4.Config
    What4.Expr What4.Expr.App What4.Expr.AppTheory
    What4.Expr.ArrayUpdateMap What4.Expr.BoolMap What4.Expr.Builder
    What4.Expr.GroundEval What4.Expr.MATLAB What4.Expr.Simplify
    What4.Expr.StringSeq What4.Expr.UnaryBV
    What4.Expr.VarIdentification What4.Expr.WeightedSum
    What4.FunctionName What4.IndexLit What4.Interface
    What4.InterpretedFloatingPoint What4.LabeledPred What4.Panic
    What4.Partial What4.ProblemFeatures What4.ProgramLoc
    What4.Protocol.Online What4.Protocol.PolyRoot
    What4.Protocol.ReadDecimal What4.Protocol.SExp
    What4.Protocol.SMTLib2 What4.Protocol.SMTLib2.Parse
    What4.Protocol.SMTLib2.Syntax What4.Protocol.SMTWriter
    What4.Protocol.VerilogWriter
    What4.Protocol.VerilogWriter.ABCVerilog
    What4.Protocol.VerilogWriter.AST
    What4.Protocol.VerilogWriter.Backend What4.SFloat What4.SWord
    What4.SatResult What4.SemiRing What4.Solver What4.Solver.Adapter
    What4.Solver.Boolector What4.Solver.CVC4 What4.Solver.DReal
    What4.Solver.ExternalABC What4.Solver.STP What4.Solver.Yices
    What4.Solver.Z3 What4.Symbol What4.Utils.AbstractDomains
    What4.Utils.AnnotatedMap What4.Utils.Arithmetic
    What4.Utils.BVDomain What4.Utils.BVDomain.Arith
    What4.Utils.BVDomain.Bitwise What4.Utils.BVDomain.XOR
    What4.Utils.Complex What4.Utils.Endian What4.Utils.Environment
    What4.Utils.FloatHelpers What4.Utils.HandleReader
    What4.Utils.IncrHash What4.Utils.LeqMap What4.Utils.MonadST
    What4.Utils.OnlyIntRepr What4.Utils.Process What4.Utils.Streams
    What4.Utils.StringLiteral What4.Utils.Versions
    What4.Utils.Word16String What4.WordMap

import-dirs:          /usr/lib/ghc-8.10.4/site-local/what4-1.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/what4-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/what4-1.1
hs-libraries:         HSwhat4-1.1-JFb2glpD9gv7gUNa55Ywhj
depends:
    attoparsec-0.14.1-94M7XwbxYJLFvYthp17dR base-4.14.1.0
    bifunctors-5.5.11-HikPGETudz6BhyS3Q9DZHc
    bimap-0.4.0-GaoUaicQEOrEAM22ryP4PA
    bv-sized-1.0.3-GXc6rLrzTL24W8Yxwu4hGo bytestring-0.10.12.0
    config-value-0.8.1-CPHuhX6Th8uAEkzmCpZEqk containers-0.6.2.1
    data-binary-ieee754-0.4.4-HlSlHq1qDaTKAKUZNW5rdz deepseq-1.4.4.0
    deriving-compat-0.5.10-6pqO9de5PzSBKEBFczBY3g directory-1.3.6.0
    exceptions-0.10.4 extra-1.7.9-LK2STTJyXXGBow2wnjywCy
    filepath-1.4.2.1 fingertree-0.1.4.2-17kmg3LKz7a94tQvQ2Kmsm
    ghc-prim-0.6.1 hashable-1.3.2.0-5x51STP8vZMKBx9J0CoY3R
    hashtables-1.2.4.1-CEhEBPUBORrGHi9wONVcXM
    io-streams-1.5.2.1-HmHtmHJvRuNG6y2xRFUWVy
    lens-5.0.1-6O7ytA0eXmiExY1VKmTl0e
    libBF-0.6.2-BFzNCt13ha92RBGCAdcW7m mtl-2.2.2
    panic-0.4.0.1-Fo4sCfDqcEkCpAt882LFEy
    parameterized-utils-2.1.3.0-vc2hmrAzfVFTqOtYjqxEE
    prettyprinter-1.7.0-HsjvX00ttaD1v9LF9JL12F process-1.6.9.0
    scientific-0.3.7.0-IzXeMiKS0G6FRSVHBIBemd template-haskell-2.16.0.0
    temporary-1.3-KC4hzhhdTjkLpKRrIYU7kN text-1.2.4.1
    th-abstraction-0.4.2.0-CPMLTlyMgmr6dbHxHL95CG
    th-lift-0.8.2-7d37mrJ37yC1VcDgqjDphG
    th-lift-instances-0.1.18-8gO3bxWkVBdGbVbGxcfZsb
    transformers-0.5.6.2
    unordered-containers-0.2.13.0-KzaktTJkN1lG5bdgci6oxQ
    utf8-string-1.0.2-7pqBkplor7g1hjwTjVt3SV
    vector-0.12.3.0-HURuJbi2iJT3pZcjBMuHYu
    versions-5.0.0-2X9dA7mF0aSFEV4kkBFmNi
    zenc-0.1.1-JvaW35gFnjuHQuX4eF5ZTK

haddock-interfaces:   /usr/share/doc/haskell-what4/html/what4.haddock
haddock-html:         /usr/share/doc/haskell-what4/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-what4-1.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-what4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 what4
version:              1.1
visibility:           public
id:                   what4-1.1-L8HwVMUNoP13RLd2rTI7Um
key:                  what4-1.1-L8HwVMUNoP13RLd2rTI7Um
license:              BSD-3-Clause
copyright:            (c) Galois, Inc 2014-2021
maintainer:           jhendrix@galois.com, rdockins@galois.com
author:               Galois Inc.
homepage:             https://github.com/GaloisInc/what4
synopsis:             Solver-agnostic symbolic values support for issuing queries
description:
    What4 is a generic library for representing values as symbolic formulae which may
    contain references to symbolic values, representing unknown variables.
    It provides support for communicating with a variety of SAT and SMT solvers,
    including Z3, CVC4, Yices, Boolector, STP, and dReal.
    The data representation types make heavy use of GADT-style type indices
    to ensure type-correct manipulation of symbolic values.

category:             Formal Methods, Theorem Provers, Symbolic Computation, SMT
abi:                  2ac24c4c82272046f8f347576ca62c1f
exposed:              True
exposed-modules:
    Test.Verification What4.BaseTypes What4.Concrete What4.Config
    What4.Expr What4.Expr.App What4.Expr.AppTheory
    What4.Expr.ArrayUpdateMap What4.Expr.BoolMap What4.Expr.Builder
    What4.Expr.GroundEval What4.Expr.MATLAB What4.Expr.Simplify
    What4.Expr.StringSeq What4.Expr.UnaryBV
    What4.Expr.VarIdentification What4.Expr.WeightedSum
    What4.FunctionName What4.IndexLit What4.Interface
    What4.InterpretedFloatingPoint What4.LabeledPred What4.Panic
    What4.Partial What4.ProblemFeatures What4.ProgramLoc
    What4.Protocol.Online What4.Protocol.PolyRoot
    What4.Protocol.ReadDecimal What4.Protocol.SExp
    What4.Protocol.SMTLib2 What4.Protocol.SMTLib2.Parse
    What4.Protocol.SMTLib2.Syntax What4.Protocol.SMTWriter
    What4.Protocol.VerilogWriter
    What4.Protocol.VerilogWriter.ABCVerilog
    What4.Protocol.VerilogWriter.AST
    What4.Protocol.VerilogWriter.Backend What4.SFloat What4.SWord
    What4.SatResult What4.SemiRing What4.Solver What4.Solver.Adapter
    What4.Solver.Boolector What4.Solver.CVC4 What4.Solver.DReal
    What4.Solver.ExternalABC What4.Solver.STP What4.Solver.Yices
    What4.Solver.Z3 What4.Symbol What4.Utils.AbstractDomains
    What4.Utils.AnnotatedMap What4.Utils.Arithmetic
    What4.Utils.BVDomain What4.Utils.BVDomain.Arith
    What4.Utils.BVDomain.Bitwise What4.Utils.BVDomain.XOR
    What4.Utils.Complex What4.Utils.Endian What4.Utils.Environment
    What4.Utils.FloatHelpers What4.Utils.HandleReader
    What4.Utils.IncrHash What4.Utils.LeqMap What4.Utils.MonadST
    What4.Utils.OnlyIntRepr What4.Utils.Process What4.Utils.Streams
    What4.Utils.StringLiteral What4.Utils.Versions
    What4.Utils.Word16String What4.WordMap

import-dirs:          /usr/lib/ghc-8.10.4/site-local/what4-1.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/what4-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/what4-1.1
hs-libraries:         HSwhat4-1.1-L8HwVMUNoP13RLd2rTI7Um
depends:
    attoparsec-0.14.1-94M7XwbxYJLFvYthp17dR base-4.14.1.0
    bifunctors-5.5.11-HikPGETudz6BhyS3Q9DZHc
    bimap-0.4.0-GaoUaicQEOrEAM22ryP4PA
    bv-sized-1.0.3-BrZ2pVGelIj2iOlx9mb60M bytestring-0.10.12.0
    config-value-0.8.1-CPHuhX6Th8uAEkzmCpZEqk containers-0.6.2.1
    data-binary-ieee754-0.4.4-HlSlHq1qDaTKAKUZNW5rdz deepseq-1.4.4.0
    deriving-compat-0.5.10-6pqO9de5PzSBKEBFczBY3g directory-1.3.6.0
    exceptions-0.10.4 extra-1.7.9-FVDdsoFVQrKF9gpq9ogElC
    filepath-1.4.2.1 fingertree-0.1.4.2-17kmg3LKz7a94tQvQ2Kmsm
    ghc-prim-0.6.1 hashable-1.3.2.0-5x51STP8vZMKBx9J0CoY3R
    hashtables-1.2.4.1-CEhEBPUBORrGHi9wONVcXM
    io-streams-1.5.2.1-HmHtmHJvRuNG6y2xRFUWVy
    lens-5.0.1-2Zjnlw4mK68FBWH0avGA3U
    libBF-0.6.2-BFzNCt13ha92RBGCAdcW7m mtl-2.2.2
    panic-0.4.0.1-Fo4sCfDqcEkCpAt882LFEy
    parameterized-utils-2.1.3.0-6MLedmP7me6EYGJy19YT8U
    prettyprinter-1.7.0-IcygC6oxBMR5rwFtc6qdvZ process-1.6.9.0
    scientific-0.3.7.0-IzXeMiKS0G6FRSVHBIBemd template-haskell-2.16.0.0
    temporary-1.3-KC4hzhhdTjkLpKRrIYU7kN text-1.2.4.1
    th-abstraction-0.4.2.0-CPMLTlyMgmr6dbHxHL95CG
    th-lift-0.8.2-7d37mrJ37yC1VcDgqjDphG
    th-lift-instances-0.1.18-8gO3bxWkVBdGbVbGxcfZsb
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-BnMT8OZ6mZf1CSW1Hvg8FR
    utf8-string-1.0.2-7pqBkplor7g1hjwTjVt3SV
    vector-0.12.3.0-HURuJbi2iJT3pZcjBMuHYu
    versions-5.0.0-2X9dA7mF0aSFEV4kkBFmNi
    zenc-0.1.1-JvaW35gFnjuHQuX4eF5ZTK

haddock-interfaces:   /usr/share/doc/haskell-what4/html/what4.haddock
haddock-html:         /usr/share/doc/haskell-what4/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
